@@ -1365,7 +1365,7 @@ Def-dict: a dictionary of dictionaries
                 if self.__Prefix is not None:
                     if self.__Prefix != '':
                         print(f"//{'-'*60}\n// {self.__Prefix}\n//{'-'*60}\n")
-                print(json.dumps(self, sort_keys=True, indent=4, cls=self.PathEncoder))
+                print(json.dumps(self.__WorkDict, sort_keys=True, indent=4, cls=self.PathEncoder))
                 if self.__Parent is None:
                     sys.exit(0)
                 return True
